"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Node = void 0;
class Node {
    constructor(_grid, x, y, blocked, weight = 1) {
        this._grid = _grid;
        this.x = x;
        this.y = y;
        this.blocked = blocked;
        this.weight = weight;
        this.opened = false;
        this.closed = false;
    }
    get f() {
        return this.g && this.h ? this.g + this.h : 0;
    }
    get grid() {
        return this._grid;
    }
    set grid(grid) {
        this._grid = grid;
    }
    get actual() {
        return this.grid.actual(this.x, this.y);
    }
    get path() {
        const path = [this];
        if (!this.parent)
            return path;
        return [...this.parent.path, ...path];
    }
    get adjacent() {
        const adjacent = [];
        if (this.grid.get(this.x - 1, this.y)) {
            adjacent.push(this.grid.get(this.x - 1, this.y));
        }
        if (this.grid.get(this.x, this.y - 1)) {
            adjacent.push(this.grid.get(this.x, this.y - 1));
        }
        if (this.grid.get(this.x + 1, this.y)) {
            adjacent.push(this.grid.get(this.x + 1, this.y));
        }
        if (this.grid.get(this.x, this.y + 1)) {
            adjacent.push(this.grid.get(this.x, this.y + 1));
        }
        return adjacent;
    }
    get neighbors() {
        const neighbors = this.adjacent;
        if (this.grid.get(this.x - 1, this.y - 1)) {
            neighbors.push(this.grid.get(this.x - 1, this.y - 1));
        }
        if (this.grid.get(this.x - 1, this.y + 1)) {
            neighbors.push(this.grid.get(this.x - 1, this.y + 1));
        }
        if (this.grid.get(this.x + 1, this.y + 1)) {
            neighbors.push(this.grid.get(this.x + 1, this.y + 1));
        }
        if (this.grid.get(this.x + 1, this.y - 1)) {
            neighbors.push(this.grid.get(this.x + 1, this.y - 1));
        }
        return neighbors;
    }
    isWithin(node, radius) {
        return (this.x >= node.x - radius &&
            this.x <= node.x + radius &&
            this.y >= node.y - radius &&
            this.y <= node.y + radius);
    }
}
exports.Node = Node;
//# sourceMappingURL=Node.js.map